import gleam/dynamic/decode
import gleam/json

pub type NewUserState {
  NewUserState
}

pub type NewUserClientMessages {
  JoinAsPlayer(token: String, user_id: Int, game_id: String)
  JoinAsHost(token: String, user_id: Int, game_id: String)
}

pub fn new_user_client_messages_decoder() -> decode.Decoder(
  NewUserClientMessages,
) {
  use variant <- decode.field("type", decode.string)
  case variant {
    "JoinAsPlayer" -> {
      use token <- decode.field("token", decode.string)
      use user_id <- decode.field("user_id", decode.int)
      use game_id <- decode.field("game_id", decode.string)
      decode.success(JoinAsPlayer(token:, user_id:, game_id:))
    }
    "JoinAsHost" -> {
      use token <- decode.field("token", decode.string)
      use user_id <- decode.field("user_id", decode.int)
      use game_id <- decode.field("game_id", decode.string)
      decode.success(JoinAsHost(token:, user_id:, game_id:))
    }
    _ -> decode.failure(JoinAsPlayer("", 0, ""), "NewUserClientMessages")
  }
}

pub type NewUserServerMessages {
  RegisterResponse
  HostRegisterResponse
}

pub fn encode_new_user_server_messages(
  new_user_server_messages: NewUserServerMessages,
) -> json.Json {
  case new_user_server_messages {
    RegisterResponse -> json.string("register_response")
    HostRegisterResponse -> json.string("host_register_response")
  }
}
